@@ -1,9 +1,10 @@
 from __future__ import absolute_import
 
-from .block import Division
-from .element import (Element, ShortElement,
+from .block import Division, Paragraph, Preformatted
+from .element import (Element, VoidElement,
                       html_attribute, boolean_html_attribute,
                       int_html_attribute)
 from .generator import (Generator, NullGenerator, ChildGenerator,
                         HTMLChildGenerator, JoinGenerator, HTMLJoinGenerator)
-from .inline import Span
+from .image import Image
+from .inline import Span, Highlight, Strong, Alternate, Emphasis, Small
