@@ -73,7 +73,7 @@ def boolean_html_attribute(attribute_name):
 
 
 def int_html_attribute(attribute_name, default=None):
-    """Add an attribute to an HTML element that accepts only integers
+    """Add an attribute to an HTML element that accepts only integers.
 
         >>> class MyElement(Element):
         ...     value = int_html_attribute("data-value")
@@ -113,6 +113,47 @@ def int_html_attribute(attribute_name, default=None):
     return property(get, set_)
 
 
+def float_html_attribute(attribute_name, default=None):
+    """Add an attribute to an HTML element that accepts only numbers.
+
+        >>> class MyElement(Element):
+        ...     value = float_html_attribute("data-value")
+        >>> element = MyElement("div")
+        >>> element.value
+        >>> str(element)
+        '<div></div>'
+        >>> element.value = 4.2
+        >>> str(element)
+        '<div data-value="4.2"></div>'
+
+    If the optional default argument is given, the attribute will not be
+    included if the value matches it.
+
+        >>> class MyElement(Element):
+        ...     value = float_html_attribute("data-value", default=0.4)
+        >>> element = MyElement("div")
+        >>> element.value
+        0.4
+        >>> str(element)
+        '<div></div>'
+
+    """
+
+    def get(self):
+        value = self.get_attribute(attribute_name, default=default)
+        if value is None:
+            return None
+        return float(value)
+
+    def set_(self, value):
+        if value is None or value == default:
+            self.remove_attribute(attribute_name)
+        else:
+            self.set_attribute(attribute_name, str(value))
+
+    return property(get, set_)
+
+
 class _ElementBase(Generator):
 
     def __init__(self, element_name):
@@ -123,7 +164,11 @@ class _ElementBase(Generator):
         self._styles = {}
 
     def set_attribute(self, name, value):
-        """Set a HTML attribute to a given string value.
+        """Set an HTML attribute to a given string value.
+
+        The validity of an attribute name is not checked, please refer to
+        the HTML standard for allowed attribute names. A good guideline is
+        to use only alphanumeric characters and dashes.
 
             >>> element = Element("div")
             >>> element.set_attribute("title", "Test Title")
@@ -164,6 +209,18 @@ class _ElementBase(Generator):
         for cls in css_classes:
             self._css_classes.add(cls)
 
+    def remove_css_classes(self, *css_classes):
+        """Remove CSS classes from this element.
+
+        Unknown classes are ignored.
+
+        """
+        for cls in css_classes:
+            try:
+                self._css_classes.remove(cls)
+            except KeyError:
+                pass
+
     def set_style(self, name, value):
         """Set a CSS style on this element.
 
@@ -285,13 +342,13 @@ class Element(_ElementBase):
         return self.children
 
 
-class ShortElement(_ElementBase):
+class VoidElement(_ElementBase):
 
     """Base generator for content-less HTML elements.
 
     These are elements like <br> or <link>.
 
-        >>> link = ShortElement("link")
+        >>> link = VoidElement("link")
         >>> link.set_attribute("rel", "stylesheet")
         >>> str(link)
         '<link rel="stylesheet"/>'
