@@ -6,7 +6,9 @@ from asserts import assert_false, assert_true, assert_equal, assert_is_none
 from htmlgen.element import (Element,
                              html_attribute,
                              boolean_html_attribute,
-                             int_html_attribute, ShortElement)
+                             int_html_attribute,
+                             float_html_attribute,
+                             VoidElement)
 
 
 class HTMLAttributeTest(TestCase):
@@ -82,6 +84,35 @@ class HTMLAttributeTest(TestCase):
         assert_equal(42, element.attr)
         assert_equal('<div></div>', str(element))
 
+    def test_float(self):
+        class MyElement(Element):
+            attr = float_html_attribute("data-attr")
+        element = MyElement("div")
+        assert_is_none(element.attr)
+        assert_equal("<div></div>", str(element))
+        element.attr = 4.2
+        assert_equal(4.2, element.attr)
+        assert_equal('<div data-attr="4.2"></div>', str(element))
+        element.attr = None
+        assert_is_none(element.attr)
+        assert_equal('<div></div>', str(element))
+
+    def test_float_with_default(self):
+        class MyElement(Element):
+            attr = float_html_attribute("data-attr", default=4.2)
+        element = MyElement("div")
+        assert_equal(4.2, element.attr)
+        assert_equal("<div></div>", str(element))
+        element.attr = 47.11
+        assert_equal(47.11, element.attr)
+        assert_equal('<div data-attr="47.11"></div>', str(element))
+        element.attr = 4.2
+        assert_equal(4.2, element.attr)
+        assert_equal('<div></div>', str(element))
+        element.attr = None
+        assert_equal(4.2, element.attr)
+        assert_equal('<div></div>', str(element))
+
 
 class ElementTest(TestCase):
 
@@ -148,6 +179,15 @@ class ElementTest(TestCase):
         css_classes.sort()
         assert_equal(["bar", "baz", "foo"], css_classes)
 
+    def test_remove_css_classes(self):
+        element = Element("div")
+        element.add_css_classes("foo", "bar", "baz")
+        element.remove_css_classes("bar", "xxx")
+        matches = re.search(r'class="(.*)"', str(element))
+        css_classes = matches.group(1).split(" ")
+        css_classes.sort()
+        assert_equal(["baz", "foo"], css_classes)
+
     def test_set_one_style(self):
         element = Element("div")
         element.set_style("background-color", "rgb(255, 0, 0)")
@@ -171,13 +211,14 @@ class ElementTest(TestCase):
         element.id = "test-id"
         assert_equal([b'<div id="test-id">', b"</div>"], list(iter(element)))
 
+
 class ShortElementTest(TestCase):
 
     def test_empty(self):
-        element = ShortElement("br")
+        element = VoidElement("br")
         assert_equal([b'<br/>'], list(iter(element)))
 
     def test_attribute(self):
-        element = ShortElement("br")
+        element = VoidElement("br")
         element.set_attribute("data-foo", "bar")
         assert_equal([b'<br data-foo="bar"/>'], list(iter(element)))
